sample_re_allocated_SNP_windows: List of selected SNP windows significantly associated with...

sample_re_allocated_SNP_windowsR Documentation

List of selected SNP windows significantly associated with shoot trait

Description

This dataset contains a list of SNP windows, each formatted as described in documentation for sample_SNP_window. This list of SNP windows includes all those within the range of 14.46Mb 14.55Mb on Chr. 10 that produced p-values between 0.01 and 0.001 in mtskat. This list was produced by using re_allocate_windows to yield a subset of SNP windows that produced p-values within the desired range.

Usage

sample_re_allocated_SNP_windows

Format

A list with 4 values


naglemi/mtmcskat documentation built on Aug. 23, 2023, 5:35 p.m.