sample_window_list: List of SNP window centers

sample_window_listR Documentation

List of SNP window centers

Description

This dataset is a list identical to that produced by the command 'seq(14460000, 14549000, by=1000)'. This is a list of SNP window positions, where each value represents the center (in base pairs) of a SNP window.

Usage

sample_window_list

Format

A list with 90 values


naglemi/mtmcskat documentation built on Aug. 23, 2023, 5:35 p.m.