| sample_window_list | R Documentation |
This dataset is a list identical to that produced by the command 'seq(14460000, 14549000, by=1000)'. This is a list of SNP window positions, where each value represents the center (in base pairs) of a SNP window.
sample_window_list
A list with 90 values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.